@@ -13,7 +13,7 @@ qx.Class.define("callbackery.ui.form.renderer.NoteForm", {
     extend : qx.ui.form.renderer.Single,
     /**
      * create a page for the View Tab with the given title
-     * 
+     *
      * @param vizWidget {Widget} visualization widget to embedd
      */
     construct: function(form) {
@@ -21,7 +21,7 @@ qx.Class.define("callbackery.ui.form.renderer.NoteForm", {
         var fl = this._getLayout();
         // have plenty of space for input, not for the labels
         fl.setColumnFlex(0, 0);
-        fl.setColumnWidth(0, 230);
+        fl.setColumnAlign(0, "left", "top");
         fl.setColumnFlex(1, 1);
         fl.setColumnMinWidth(1, 130);
     },
@@ -34,7 +34,7 @@ qx.Class.define("callbackery.ui.form.renderer.NoteForm", {
                     this._createHeader(title), {row: this._row, column: 0, colSpan: 3}
                 );
                 this._row++;
-                if (headerOptions != null && headerOptions.note != null){ 
+                if (headerOptions != null && headerOptions.note != null){
                     this._add(new qx.ui.basic.Label(headerOptions.note).set({
                         rich: true,
                         alignX: 'left'
@@ -56,7 +56,7 @@ qx.Class.define("callbackery.ui.form.renderer.NoteForm", {
                         marginLeft: 20,
                         marginRight: 20
                     }),{
-                        row: this._row, 
+                        row: this._row,
                         column: 2
                     });
                 }
@@ -69,4 +69,4 @@ qx.Class.define("callbackery.ui.form.renderer.NoteForm", {
          }
         }
     }
-});       
+});
